==> v1.1.6.zip: siyuan/README_zh_CN.md <==
<p align="center">
<img alt="SiYuan" src="https://b3log.org/images/brand/siyuan-128.png">
<br>
<em>下一代的个人知识管理系统，你的数字花园</em>
<br><br>
<a title="Releases" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release/siyuan-note/siyuan.svg?style=flat-square&color=FF9900"></a>
<a title="Downloads" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/downloads/siyuan-note/siyuan/total.svg?style=flat-square&color=blueviolet"></a>
<a title="Docker Pulls" target="_blank" href="https://hub.docker.com/r/b3log/siyuan"><img src="https://img.shields.io/docker/pulls/b3log/siyuan.svg?logo=docker&style=flat-square&color=99CCFF"></a>
<a title="Discord" target="_blank" href="https://discord.gg/bzfCBwMzdP"><img src="https://img.shields.io/discord/808152298789666826?label=discord&logo=discord&style=flat-square&color=orange"></a>
<a title="Hits" target="_blank" href="https://github.com/siyuan-note/siyuan"><img src="https://hits.b3log.org/siyuan-note/siyuan.svg"></a>
</p>

<p align="center">
<a href="https://github.com/siyuan-note/siyuan/blob/master/README.md">English</a>
</p>

## 💡 简介

思源笔记是一款本地离线优先的个人知识管理系统， 支持细粒度块级引用和 Markdown 即时渲染编辑。

[分享发布空间在线体验](https://ld246.com/udanax/1602224134353)，欢迎到[思源笔记官方讨论区](https://ld246.com/domain/siyuan)了解更多。

![bg1.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@762fc276da1f713551b61799f04a3661ccd17369/screenshots/bg1.png)

![bg3.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@762fc276da1f713551b61799f04a3661ccd17369/screenshots/bg3.png)

## ✨  特性

* 内容块
  * 块级引用和双向链接
  * 文档关系图、全局关系图
  * 书签收藏
  * 动态查询嵌入
  * 提供 URL 浏览器访问或给其他软件链接
* 为 Markdown 而生
  * 类似 Typora 的即时渲染编辑模式
  * 支持数学公式、图表、流程图、甘特图、时序图、五线谱等
  * 粘贴 HTML 自动转换为 Markdown
  * 配置 Markdown 解析渲染细节参数  
* 脑图模式
  * 支持缩放、拖拽、布局、主题等
  * 编辑和 Markdown 保持同步
* 支持浏览器使用、支持移动端
* 层级标签
* 多窗口多页签，拖拽分屏
* WebDAV
* 全文搜索
* 主题和图标
  * 内置明亮、暗黑两套主题
  * 内置 Material、Ant Design 两套图标
  * 支持自定义主题和图标
* 导出
  * 标准 Markdown 和 TextBundle 导出
  * 内容块引用提供锚文本 + 嵌入 Blockquote 选项
  * 复制到微信公众号、知乎和语雀
* 版本管理和同步
  * [在线工作空间](https://ld246.com/xanadu/)
  * [在线分享发布](https://ld246.com/udanax/)

## 🗺️ 路线图

* [思源笔记开发计划和进度](https://github.com/siyuan-note/siyuan/projects)
* [思源笔记版本变更记录](https://github.com/siyuan-note/siyuan/blob/master/CHANGE_LOGS.md)

## 🛠️ 下载安装

* [B3log](https://b3log.org/siyuan/download.html)
* [GitHub](https://github.com/siyuan-note/siyuan/releases)
* [Docker](https://hub.docker.com/r/b3log/siyuan)

获取最新内部预览版（Insider Preview），请<a href="https://jq.qq.com/?_wv=1027&k=brIyNm7y" target="_blank">加入 Q 群</a>或者将你的 GitHub 登录名发送邮件至 845765@qq.com，我们将邀请你加入 SiYuan 内部预览团队。

## 📜 文档

* [用户指南](https://ld246.com/udanax/1602224134353)
* [思源笔记 - 支持 Markdown 块级引用和双向链接的网状笔记应用](https://ld246.com/article/1598872180233)
* [Markdown 实现块级引用双向链接的探索](https://ld246.com/article/1597226949061)

## 🏘️ 社区

* [中文讨论区](https://ld246.com/domain/siyuan)
* [Discord](https://discord.gg/bzfCBwMzdP)

## 💌 参与贡献

目前思源笔记的一些组件是开源的，欢迎参与贡献。

* [用户指南](https://github.com/siyuan-note/user-guide-zh_CN)
* [外观和语言](https://github.com/siyuan-note/appearance)
* [Markdown 引擎](https://github.com/88250/lute)

## 🙏 鸣谢

思源笔记的诞生离不开 [Vditor](https://github.com/Vanessa219/vditor) 和 [Lute](https://github.com/88250/lute) 开源项目以及下列开源项目。

<details>
<summary>内核</summary>

* [https://github.com/golang/go](https://github.com/golang/go) `BSD-3-Clause License`
* [https://github.com/vanng822/css](https://github.com/vanng822/css) `MIT License`
* [https://github.com/studio-b12/gowebdav](https://github.com/studio-b12/gowebdav) `BSD-3-Clause License`
* [https://github.com/88250/gulu](https://github.com/88250/gulu) `Mulan PSL v2`
* [https://github.com/olahol/melody](https://github.com/olahol/melody) `BSD-2-Clause License`
* [https://github.com/Masterminds/sprig](https://github.com/Masterminds/sprig) `MIT License`
* [https://github.com/Xuanwo/go-locale](https://github.com/Xuanwo/go-locale) `Apache-2.0 License`
* [https://github.com/blastrain/vitess-sqlparser](https://github.com/blastrain/vitess-sqlparser) `Apache-2.0 License`
* [https://github.com/common-nighthawk/go-figure](https://github.com/common-nighthawk/go-figure) `MIT License`
* [https://github.com/dustin/go-humanize](https://github.com/dustin/go-humanize) `MIT License`
* [https://github.com/emirpasic/gods](https://github.com/emirpasic/gods) `BSD-2-Clause License`
* [https://github.com/facette/natsort](https://github.com/facette/natsort) `BSD-3-Clause License`
* [https://github.com/fsnotify/fsnotify](https://github.com/fsnotify/fsnotify) `BSD-3-Clause License`
* [https://github.com/gin-contrib/cors](https://github.com/gin-contrib/cors) `MIT License`
* [https://github.com/gin-gonic/gin](https://github.com/gin-gonic/gin) `MIT License`
* [https://github.com/go-git/go-git](https://github.com/go-git/go-git) `Apache-2.0 License`
* [https://github.com/jackpal/gateway](https://github.com/jackpal/gateway) `BSD-3-Clause License`
* [https://github.com/mitchellh/go-ps](https://github.com/mitchellh/go-ps) `MIT License`
* [https://github.com/mssola/user_agent](https://github.com/mssola/user_agent) `MIT License`
* [https://github.com/panjf2000/ants](https://github.com/panjf2000/ants) `MIT License`
* [https://github.com/parnurzeal/gorequest](https://github.com/parnurzeal/gorequest) `MIT License`
* [https://github.com/golang/crypto](https://github.com/golang/crypto) `BSD-3-Clause License`
* [https://github.com/golang/net](https://github.com/golang/net) `BSD-3-Clause License`
* [https://github.com/golang/text](https://github.com/golang/text) `BSD-3-Clause License`
* [https://github.com/go-gorm/sqlite](https://github.com/go-gorm/sqlite) `MIT License`
* [https://github.com/go-gorm/gorm](https://github.com/go-gorm/gorm) `MIT License`
</details>

<details>
<summary>界面</summary>

* [https://github.com/microsoft/TypeScript](https://github.com/microsoft/TypeScript) `Apache-2.0 License`
* [https://github.com/electron/electron](https://github.com/electron/electron) `MIT License`
* [https://github.com/d3/d3](https://github.com/d3/d3) `BSD-3-Clause License`
* [https://github.com/google/diff-match-patch](https://github.com/google/diff-match-patch) `Apache-2.0 License`
* [https://github.com/rtfpessoa/diff2html](https://github.com/rtfpessoa/diff2html) `MIT License`
* [https://github.com/mozilla/pdfjs-dist](https://github.com/mozilla/pdfjs-dist) `Apache-2.0 License`
* [https://github.com/blueimp/JavaScript-MD5](https://github.com/blueimp/JavaScript-MD5) `MIT License`
* [https://github.com/fex-team/kityminder-core](https://github.com/fex-team/kityminder-core) `BSD-3-Clause License`
* [https://github.com/codemirror/CodeMirror](https://github.com/codemirror/CodeMirror) `MIT License`
* [https://github.com/hakimel/reveal.js](https://github.com/hakimel/reveal.js) `MIT License`
</details>

==> v1.2.2.zip: siyuan/README_zh_CN.md <==
<p align="center">
<img alt="SiYuan" src="https://b3log.org/images/brand/siyuan-128.png">
<br>
<em>下一代的个人知识管理系统，你的数字花园</em>
<br><br>
<a title="Releases" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release/siyuan-note/siyuan.svg?style=flat-square&color=FF9900"></a>
<a title="Downloads" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/downloads/siyuan-note/siyuan/total.svg?style=flat-square&color=blueviolet"></a>
<a title="Docker Pulls" target="_blank" href="https://hub.docker.com/r/b3log/siyuan"><img src="https://img.shields.io/docker/pulls/b3log/siyuan.svg?logo=docker&style=flat-square&color=99CCFF"></a>
<a title="Discord" target="_blank" href="https://discord.gg/bzfCBwMzdP"><img src="https://img.shields.io/discord/808152298789666826?label=discord&logo=discord&style=flat-square&color=orange"></a>
<a title="Hits" target="_blank" href="https://github.com/siyuan-note/siyuan"><img src="https://hits.b3log.org/siyuan-note/siyuan.svg"></a>
</p>

<p align="center">
<a href="https://github.com/siyuan-note/siyuan/blob/master/README.md">English</a>
</p>

## 💡 简介

思源笔记是一款本地优先的个人知识管理系统， 支持细粒度块级引用和 Markdown 所见即所得。

欢迎到[思源笔记官方讨论区](https://ld246.com/domain/siyuan)了解更多。

![feature0.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@8489397401cf5025eab847dfb26a4f3896be5363/screenshots/feature0.png)

![feature1-1.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@8489397401cf5025eab847dfb26a4f3896be5363/screenshots/feature1-1.png)

## ✨  特性

* 内容块
  * 块级引用和双向链接
  * 文档关系图、全局关系图
  * 自定义属性
  * SQL 查询嵌入
  * 协议 `siyuan://`
* 编辑器
  * Block 风格
  * Markdown 所见即所得
  * 列表大纲
  * 块缩放聚焦
  * 块横向排版
  * 百万字大文档编辑
  * 数学公式、图表、流程图、甘特图、时序图、五线谱等
  * 网页剪藏
* 导出
  * 带 assets 文件夹的标准 Markdown
  * 内容块引用提供锚文本 + 嵌入 Blockquote 选项
  * 复制到微信公众号、知乎和语雀
* 层级标签
* 多页签拖拽分屏
* 全文搜索
* 模板片段
* 快捷键
* 主题和图标
* 数据云端备份，端到端加密
* Android APP
* Docker 部署

## 🗺️ 路线图

* [思源笔记开发计划和进度](https://github.com/siyuan-note/siyuan/projects)
* [思源笔记版本变更和公告](https://ld246.com/tag/siyuan-announcement)

## 🛠️ 下载安装

* [B3log](https://b3log.org/siyuan/download.html)
* [GitHub](https://github.com/siyuan-note/siyuan/releases)
* [Docker](https://hub.docker.com/r/b3log/siyuan)

获取最新内部预览版（Insider Preview），请将你的 GitHub 登录名发送邮件至 845765@qq.com，我们将邀请你加入 SiYuan 内部预览团队。

## 📜 文档

* [思源笔记 - 支持 Markdown 块级引用和双向链接的网状笔记应用](https://ld246.com/article/1598872180233)
* [Markdown 实现块级引用双向链接的探索](https://ld246.com/article/1597226949061)

## 🏘️ 社区

* [中文讨论区](https://ld246.com/domain/siyuan)
* [Discord](https://discord.gg/bzfCBwMzdP)

## 💌 参与贡献

目前思源笔记的一些组件是开源的，欢迎参与贡献。

* [用户指南](https://github.com/siyuan-note/user-guide-zh_CN)
* [外观](https://github.com/siyuan-note/appearance)
* [Markdown 引擎](https://github.com/88250/lute)
* [Chrome 扩展](https://github.com/siyuan-note/siyuan-chrome)

## 🙏 鸣谢

思源的诞生离不开 [Vditor](https://github.com/Vanessa219/vditor) 和 [Lute](https://github.com/88250/lute) 开源项目以及下列开源项目。

* [https://github.com/golang/go](https://github.com/golang/go) `BSD-3-Clause License`
* [https://github.com/vanng822/css](https://github.com/vanng822/css) `MIT License`
* [https://github.com/88250/gulu](https://github.com/88250/gulu) `Mulan PSL v2`
* [https://github.com/olahol/melody](https://github.com/olahol/melody) `BSD-2-Clause License`
* [https://github.com/Masterminds/sprig](https://github.com/Masterminds/sprig) `MIT License`
* [https://github.com/Xuanwo/go-locale](https://github.com/Xuanwo/go-locale) `Apache-2.0 License`
* [https://github.com/blastrain/vitess-sqlparser](https://github.com/blastrain/vitess-sqlparser) `Apache-2.0 License`
* [https://github.com/common-nighthawk/go-figure](https://github.com/common-nighthawk/go-figure) `MIT License`
* [https://github.com/dustin/go-humanize](https://github.com/dustin/go-humanize) `MIT License`
* [https://github.com/emirpasic/gods](https://github.com/emirpasic/gods) `BSD-2-Clause License`
* [https://github.com/facette/natsort](https://github.com/facette/natsort) `BSD-3-Clause License`
* [https://github.com/fsnotify/fsnotify](https://github.com/fsnotify/fsnotify) `BSD-3-Clause License`
* [https://github.com/gin-gonic/gin](https://github.com/gin-gonic/gin) `MIT License`
* [https://github.com/jackpal/gateway](https://github.com/jackpal/gateway) `BSD-3-Clause License`
* [https://github.com/mitchellh/go-ps](https://github.com/mitchellh/go-ps) `MIT License`
* [https://github.com/mssola/user_agent](https://github.com/mssola/user_agent) `MIT License`
* [https://github.com/panjf2000/ants](https://github.com/panjf2000/ants) `MIT License`
* [https://github.com/parnurzeal/gorequest](https://github.com/parnurzeal/gorequest) `MIT License`
* [https://github.com/microsoft/TypeScript](https://github.com/microsoft/TypeScript) `Apache-2.0 License`
* [https://github.com/electron/electron](https://github.com/electron/electron) `MIT License`
* [https://github.com/visjs/vis-network](https://github.com/visjs/vis-network) `Apache-2.0 License`
* [https://github.com/google/diff-match-patch](https://github.com/google/diff-match-patch) `Apache-2.0 License`
* [https://github.com/rtfpessoa/diff2html](https://github.com/rtfpessoa/diff2html) `MIT License`
* [https://github.com/mozilla/pdfjs-dist](https://github.com/mozilla/pdfjs-dist) `Apache-2.0 License`
* [https://github.com/blueimp/JavaScript-MD5](https://github.com/blueimp/JavaScript-MD5) `MIT License`
* [https://github.com/fex-team/kityminder-core](https://github.com/fex-team/kityminder-core) `BSD-3-Clause License`
* [https://github.com/hakimel/reveal.js](https://github.com/hakimel/reveal.js) `MIT License`
